export declare type groupFN = (t: TSTestGroup) => Promise<void>;
export declare type unaryFN = (t: TSUnaryTest) => Promise<void>;
export declare type testFN = (t: TSTest) => Promise<void>;
export declare class TSTester {
    groups: TSTestGroup[];
    desc: string;
    constructor(s: string);
    addGroup(grp: TSTestGroup): void;
    addGroups(grps: TSTestGroup | TSTestGroup[]): void;
    log(format: string, ...args: any[]): void;
    run(): Promise<void>;
}
export declare class TSTest {
    desc: string;
    fn: testFN;
    protected constructor(s: string, f: testFN);
    static group(s: string, f: groupFN): TSTestGroup;
    run(): Promise<[number, number]>;
    log(format: string, ...args: any[]): void;
}
export declare class TSTestGroup extends TSTest {
    private _unaries;
    constructor(s: string, f: groupFN);
    unary(s: string, f: unaryFN): void;
    description(str: string): void;
    prepare(): Promise<void>;
    log(format: string, ...args: any[]): void;
    run(): Promise<[number, number]>;
}
export declare class TSTestDescriptor extends TSTest {
    constructor(s: string);
    log(format: string, ...args: any[]): void;
    run(): Promise<[number, number]>;
}
export declare class TSUnaryTest extends TSTest {
    _group: TSTestGroup;
    private _failed;
    private _passed;
    private _expected;
    private _registrations;
    constructor(g: TSTestGroup, s: string, f: unaryFN);
    log(format: string, ...args: any[]): void;
    run(): Promise<[number, number]>;
    register(name: string, value: any): void;
    printRegistrations(): void;
    expect(v: any, msg?: string): TSExpectAgent;
    expect0(v: any): TSExpectAgent;
    expect1(v: any): TSExpectAgent;
    expect2(v: any): TSExpectAgent;
    expect3(v: any): TSExpectAgent;
    expect4(v: any): TSExpectAgent;
    expect5(v: any): TSExpectAgent;
    expect6(v: any): TSExpectAgent;
    expect7(v: any): TSExpectAgent;
    expect8(v: any): TSExpectAgent;
    expect9(v: any): TSExpectAgent;
    expectA(v: any): TSExpectAgent;
    expectB(v: any): TSExpectAgent;
    expectC(v: any): TSExpectAgent;
    expectD(v: any): TSExpectAgent;
    expectE(v: any): TSExpectAgent;
    expectF(v: any): TSExpectAgent;
    expectG(v: any): TSExpectAgent;
    expectH(v: any): TSExpectAgent;
    expectI(v: any): TSExpectAgent;
    expectJ(v: any): TSExpectAgent;
    expectK(v: any): TSExpectAgent;
    expectL(v: any): TSExpectAgent;
    expectM(v: any): TSExpectAgent;
    expectN(v: any): TSExpectAgent;
    expectO(v: any): TSExpectAgent;
    expectP(v: any): TSExpectAgent;
    expectQ(v: any): TSExpectAgent;
    expectR(v: any): TSExpectAgent;
    expectS(v: any): TSExpectAgent;
    expectT(v: any): TSExpectAgent;
    expectU(v: any): TSExpectAgent;
    expectV(v: any): TSExpectAgent;
    expectW(v: any): TSExpectAgent;
    expectX(v: any): TSExpectAgent;
    expectY(v: any): TSExpectAgent;
    expectZ(v: any): TSExpectAgent;
    fail(): boolean;
    pass(): boolean;
}
export declare class TSExpectAgent {
    private _value;
    private _step;
    private _message;
    constructor(step: TSUnaryTest, value: any, msg?: string);
    toBe(aValue: any): boolean;
    notToBe(aValue: any): boolean;
    toBeTruthy(): boolean;
    toBeFalsy(): boolean;
    toBeUndefined(): boolean;
    toBeDefined(): boolean;
    toBeNull(): boolean;
    toBeNotNull(): boolean;
    toBeOK(): boolean;
    toBeNotOK(): boolean;
    toBeNaN(): boolean;
    toBeANumber(): boolean;
    toBeAnInt(): boolean;
    toBeAnUnsigned(): boolean;
    toBeAString(): boolean;
    toBeBool(): boolean;
    toBeAnEmail(): boolean;
    toBeAnUrl(): boolean;
    toBeAnUUID(): boolean;
    toBeAnObject(): boolean;
    toBeArray(): boolean;
    toBeADate(): boolean;
    toBeAFunction(): boolean;
    eq(aValue: any): boolean;
    neq(aValue: any): boolean;
    gt(aValue: any): boolean;
    gte(aValue: any): boolean;
    lt(aValue: any): boolean;
    lte(aValue: any): boolean;
    private _compfail;
    private _elogfail;
    private _nelogfail;
    private _writeMessage;
}
